==> blanco.plugin.dbee_1.2.0-src.zip: blancoDbPlugin/src/blanco/plugin/dbee/wizards/BlancoDbEEWizardPage2.java <==
package blanco.plugin.dbee.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

public class BlancoDbEEWizardPage2 extends WizardPage {

    private ISelection selection;

    public BlancoDbEEWizardPage2(ISelection selection) {
        super("wizardPage");
        setTitle("blancoDbEȄЉ");
        this.selection = selection;
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoDb Enterprise Edition (blancoDbEE) ͉L̂悤ȃc[łB");
        new Label(container, SWT.NONE).setText("  1.R/O}bsOc[");
        new Label(container, SWT.NONE)
                .setText("    JDBCpf[^x[XvO~Ȏ啔邱Ƃł܂B");
        new Label(container, SWT.NONE).setText("    SQL͂Ƃă}bsO쐬܂B");
        new Label(container, SWT.NONE)
                .setText("    O/R}bsOƑSt̃Av[`ɂ}bsO񋟂܂B");
        new Label(container, SWT.NONE).setText("  2.\[XR[h^Cv");
        new Label(container, SWT.NONE)
                .setText("    ʂJDBCf[^x[XvO~Õ\[XR[h쐬肵܂B");
        new Label(container, SWT.NONE)
                .setText("    sɓ̃Cu(*.jar)t@CKvƂ܂B");
        new Label(container, SWT.NONE).setText("  3.hLgw");
        new Label(container, SWT.NONE).setText("    SQL`t@C͂Ƃē삵܂B");
        new Label(container, SWT.NONE)
                .setText("    hLgwł邽߁AhLgƃ\[XR[hƂ̓ɂĎRɎ邱Ƃo܂B");

        setControl(container);
    }
}

==> blanco.plugin.dbee_1.9.4-src.zip: blancoDbPlugin/src/blanco/plugin/dbee/wizards/BlancoDbEEWizardPage2.java <==
/*
 * blancoDb Enterprise Edition
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.dbee.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

public class BlancoDbEEWizardPage2 extends WizardPage {

    public BlancoDbEEWizardPage2(ISelection selection) {
        super("wizardPage");
        setTitle("blancoDbEȄЉ");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoDb Enterprise Edition (blancoDbEE) ͉L̂悤ȃc[łB");
        new Label(container, SWT.NONE).setText("  1.R/O}bsOc[");
        new Label(container, SWT.NONE)
                .setText("    JDBCpf[^x[XvO~Ȏ啔邱Ƃł܂B");
        new Label(container, SWT.NONE).setText("    SQL͂Ƃă}bsO쐬܂B");
        new Label(container, SWT.NONE)
                .setText("    O/R}bsOƑSt̃Av[`ɂ}bsO񋟂܂B");
        new Label(container, SWT.NONE).setText("  2.\[XR[h^Cv");
        new Label(container, SWT.NONE)
                .setText("    ʂJDBCf[^x[XvO~Õ\[XR[h쐬肵܂B");
        new Label(container, SWT.NONE)
                .setText("    sɓ̃Cu(*.jar)t@CKvƂ܂B");
        new Label(container, SWT.NONE).setText("  3.hLgw");
        new Label(container, SWT.NONE).setText("    SQL`͂Ƃē삵܂B");
        new Label(container, SWT.NONE)
                .setText("    hLgwł邽߁AhLgƃ\[XR[hƂ̓ɂĎRɎ邱Ƃo܂B");

        setControl(container);
    }
}
